@@ -133,6 +133,7 @@ class Bootstrap:
         add_arg("website", help="name of website")
         add_arg("package", help="name of PyPI package to install")
         add_arg("app", help="name of web app to run")
+        add_arg("--domain", help="domain name of website")
 
     def run(self, stdin, log):
         logging.basicConfig(
@@ -189,8 +190,9 @@ class Bootstrap:
             console.print("Installing firewall")
             machine._apt("install -yq ufw")
             machine.open_ports(22)
-            console.print("Setting up system")
+            console.print("Installing system software")
             machine.setup_machine()
+            # TODO console.print("Starting to mine for onion")
             console.print("Installing python")
             machine.setup_python()
             console.print("Installing tor")
@@ -203,6 +205,7 @@ class Bootstrap:
             machine.setup_nginx()
             console.print(f"Installing application: {self.app} of {self.package}")
             machine.setup_app(self.package, self.app, config["host_token"], secret)
+            # TODO console.print("Configuring domain name")
             time.sleep(2)
         console.rule(
             f"[green]Bootstrapped {self.package} ({self.app}) at {machine.address}"
