@@ -493,16 +493,23 @@ class Machine(MachineBase):
         self.run(f"openssl dhparam -out {self.nginx_conf}/dhparam.pem {bits}")
         self.run("service nginx restart")
 
-    def setup_app(self, package, app, do_token=None):
+    def setup_app(self, package, app, do_token=None, secret=None):
         """Install administrative interface."""
         self.user = "gaea"
         self.run("python3 -m venv app")
         self.run(f"mkdir {self.run_dir}")
+
+        webcfg = {}
         if do_token:
+            webcfg["digitalocean_token"] = do_token
+        if secret:
+            webcfg["secret"] = secret
+        if webcfg:
             self.run(
                 f"cat > {self.run_dir}/webcfg.ini",
-                stdin=f'DIGITALOCEAN_TOKEN = "{do_token}"',
+                stdin="\n".join(f'{k.upper()} = "{v}"' for k, v in webcfg.items()),
             )
+
         self.run(f"{self.runinenv} app pip install {package}")
         self.user = "root"
         with self.supervisor(package) as config:
